# wagtailosm

[![pypi badge](https://badge.fury.io/py/wagtailosm.png)](http://badge.fury.io/py/wagtailosm)

Open Street Map integration for Wagtail

2025 update! Now updated and tested for Wagtail 5.2+!

Features
--------

Simple integration of OpenStreetMaps for Wagtail using the `osm_field` implementation. Use it as with `osm_field`: If you want maps but don't need GIS. What it does is to maintain three columns in your database, one for latitude, one for longitude, and one for the "text search" that you have used to initially place the dot on the map in the admin.

Usage: [See docs](http://wagtailosm.readthedocs.org/en/latest/usage.html).

How it looks
------------

![image of interface](./screen.png)

Improvements?
-------------

This project took about 2 hours. Then it was updated in about 1 hour 5 years later. It has no tests, please just test in a real environment and feel welcome to send back improvements or make it your own!